def binning(df, n_bins: int, numeric_col_list: list[str] | None = None):
    """
    Bins specified numeric columns in the DataFrame into a specified number of quantile-based bins.
    If no columns are specified, all numeric columns will be binned.

    Parameters:
    - df: DataFrame containing the dataset.
    - n_bins: The number of bins to divide each numeric column into.
    - numeric_col_list: Optional list of numeric column names to bin. If None, all numeric columns are considered.

    Returns:
    - A DataFrame with specified numeric columns replaced by their binned integer representations.
    """
    import pandas as pd

    # If no specific columns provided, use all numeric columns
    if numeric_col_list is None:
        numeric_col_list = df.select_dtypes(include=['number']).columns.tolist()

    for col in numeric_col_list:
        if col in df.columns:
            df[f'{col}_binned'] = pd.qcut(df[col], q=n_bins, duplicates='drop', labels=False)
        else:
            print(f"Warning: Column '{col}' not found in DataFrame. Skipping.")

    return df
